==> nextcloud-app-spreed-1%3A19.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "Guest" : "I ftuar",
    "File is too big" : "Skedari është shumë i madh",
    "Invalid file provided" : "U dha kartelë e pavlefshme",
    "Invalid image" : "Figurë e pavlefshme",
    "Unknown filetype" : "Lloj i panjohur skedari",
    "Dismiss notification" : "Hiq lajmërimin",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Open settings" : "Hap rregullimet",
    "error" : "gabim",
    "Conversations" : "Bisedat",
    "Avatar image is not square" : "Imazhi avatar nuk është katror",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
    "Afghanistan" : "Afganistani",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Shqipëria",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktiku",
    "Argentina" : "Argjentina",
    "American Samoa" : "Samoa Amerikane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ishujt Oland",
    "Azerbaijan" : "Azerbajxhani",
    "Bosnia and Herzegovina" : "Bosnja and Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgjika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bullgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butani",
    "Botswana" : "Botsvana",
    "Belarus" : "Bjellorusi",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Zvicër",
    "Côte d'Ivoire" : "Bregu i Fildishtë",
    "Chile" : "Kili",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbi",
    "Cuba" : "Kubë",
    "Cabo Verde" : "Kepi i Gjelbër",
    "Cyprus" : "Qipro",
    "Germany" : "Gjermani",
    "Denmark" : "Danimarkë",
    "Algeria" : "Algjeria",
    "Ecuador" : "Ekuadori",
    "Estonia" : "Estonia",
    "Egypt" : "Egjipt",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlanda",
    "Fiji" : "Fixhi",
    "France" : "Franca",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Mbretëria e Bashkuar e Britanisë së Madhe dhe Irlandës Veriore",
    "Georgia" : "Gjeorgji",
    "Ghana" : "Gana",
    "Gibraltar" : "Gjibraltar",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Greece" : "Greqi",
    "Guatemala" : "Guatemala",
    "Honduras" : "Honduras",
    "Croatia" : "Kroaci",
    "Haiti" : "Haiti",
    "Hungary" : "Hungari",
    "Indonesia" : "Indonezia",
    "Ireland" : "Irlanda",
    "Israel" : "Izraeli",
    "India" : "India",
    "Iraq" : "Irak",
    "Iceland" : "Islanda",
    "Italy" : "Itali",
    "Jamaica" : "Xhamaika",
    "Jordan" : "Jordani",
    "Japan" : "Japoni",
    "Kenya" : "Kenia",
    "Cambodia" : "Kamboxhia",
    "Kiribati" : "Kiribati",
    "Kuwait" : "Kuvajti",
    "Kazakhstan" : "Kazakistani",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luksemburgu",
    "Libya" : "Libia",
    "Morocco" : "Maroku",
    "Montenegro" : "Mali i Zi",
    "Mali" : "Mali",
    "Mongolia" : "Mongolia",
    "Malta" : "Malta",
    "Mexico" : "Meksikë",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollandë",
    "Norway" : "Norvegji",
    "Nepal" : "Nepal",
    "New Zealand" : "Zelanda e Re",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Poloni",
    "Puerto Rico" : "Puerto Riko",
    "Portugal" : "Portugali",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Qatar",
    "Romania" : "Rumania",
    "Serbia" : "Serbi",
    "Russian Federation" : "Federata Ruse",
    "Saudi Arabia" : "Arabia Saudite",
    "Sudan" : "Sudan",
    "Sweden" : "Suedi",
    "Singapore" : "Singapori",
    "Slovenia" : "Sllovenia",
    "Slovakia" : "Sllovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegali",
    "Somalia" : "Somalia",
    "Syrian Arab Republic" : "Republika Arabe e Sirisë",
    "Chad" : "Çad",
    "Togo" : "Togo",
    "Thailand" : "Tajlanda",
    "Tajikistan" : "Taxhikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tonga",
    "Turkey" : "Turqi",
    "Ukraine" : "Ukrainë",
    "Uganda" : "Uganda",
    "United States of America" : "Shtetet e Bashkuara të Amerikës",
    "Uruguay" : "Uruguaj",
    "Zambia" : "Zambia",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Leave call" : "Lini një thirrje",
    "Limit to groups" : "Kufizo grupet",
    "Everyone" : "Kushdo",
    "Save changes" : "Ruaj ndryshimet",
    "Saved!" : "I/E ruajtur!",
    "State" : "Gjendja",
    "Name" : "Emri",
    "Description" : "Përshkrim",
    "Enabled" : "E aktivizuar",
    "Disabled" : "I çaktivizuar",
    "Federation" : "Federim",
    "Permissions" : "Lejet",
    "General settings" : "Opsjonet e Pergjithshme",
    "Language" : "Gjuha",
    "Country" : "Vend",
    "Status" : "Status",
    "Created at" : "U krijua në",
    "Pending" : "Në Pritje të Konfirmimit",
    "Error" : "Error",
    "Blocked" : "I bllokuar",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "OK" : "OK",
    "Checking …" : "Duke kontrolluar ...",
    "Back" : "Prapa",
    "Cancel" : "Anullo",
    "Confirm" : "Konfirmo",
    "Reset" : "Rivendos",
    "Copy link" : "Kopjo linkun",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Mute audio" : "Mute audio",
    "Disable video" : "Çaktivizo video",
    "You" : "Ju",
    "Collapse" : "Tkurre",
    "Favorite" : "I/E Preferuar",
    "Hide details" : "Fsheh detajet",
    "Disable" : "Çaktivizoje",
    "Enable" : "Aktivizoje",
    "Choose" : "Zgjidhni",
    "Restricted" : "I/E kufizuar",
    "Personal" : "Personale",
    "Leave conversation" : "Largohuni nga biseda",
    "Delete conversation" : "Fshijeni bisedën",
    "Yes" : "Po",
    "Password protection" : "Password protection",
    "Save" : "Ruaj",
    "Edit" : "Përpuno",
    "Delete" : "Fshij",
    "Log content" : "Përmbajtja e hyrjes",
    "User" : "Përdorues",
    "Password" : "Fjalëkalim",
    "API token" : "Çelës identifikues i API-t ",
    "Login" : "Hyrje",
    "Nickname" : "Nofkë",
    "Client ID" : "ID klienti",
    "Notifications" : "Njoftimet",
    "Mark as read" : "Shënoje si të lexuar",
    "Mark as unread" : "Shënoje si të palexuar",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "Users" : "Përdoruesit",
    "Groups" : "Grupet",
    "Loading" : "Duke ngarkuar",
    "None" : "Asnjë",
    "Devices" : "Pajisjet",
    "Upload" : "Ngarkoni",
    "Files" : "Skedarët",
    "Message sent" : "Mesazhi u dërgua",
    "Reply" : "Përgjigju",
    "Translate" : "Përkthe",
    "Dismiss" : "Hiq",
    "Contact" : "Kontakt",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
    "Close" : "Mbylleni",
    "Password protect" : "Mbroje me fjalëkalim",
    "Send message" : "Dërgo mesazh",
    "Group" : "Grup",
    "Create new poll" : "Krijo sondazh të ri",
    "New file" : "Skedë e re",
    "Settings" : "Rregullimet",
    "Create poll" : "Krijo sondazh",
    "Send" : "Dërgo",
    "guest" : "vizitor",
    "Remove" : "Hiqe",
    "No results" : "Asnjë rezultat",
    "Add users or groups" : "Add users or groups",
    "Details" : "Detajet",
    "Privacy" : "Privatësia",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Search" : "Kërko",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "Grid view" : "Pamje galeri",
    "Submit" : "Dërgo",
    "Media" : "Media",
    "Polls" : "Sondazhe",
    "Audio" : "Audio",
    "Other" : "Tjetër",
    "Default" : "E paracaktuar",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
    "Android app" : "Aplikacion Android",
    "iOS app" : "Aplikacion iOS",
    "Circles" : "Rrethet",
    "Open sidebar" : "Hapni sidebar-in",
    "Start a conversation" : "Filloni një bisedë",
    "TURN server" : "Serveri TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A21.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "Guest" : "I ftuar",
    "System" : "Sistem",
    "File is too big" : "Skedari është shumë i madh",
    "Invalid file provided" : "U dha kartelë e pavlefshme",
    "Invalid image" : "Figurë e pavlefshme",
    "Unknown filetype" : "Lloj i panjohur skedari",
    "Description" : "Përshkrim",
    "Dismiss notification" : "Hiq lajmërimin",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "New message" : "Mesazh i ri",
    "Open settings" : "Hap rregullimet",
    "error" : "gabim",
    "Conversations" : "Bisedat",
    "Avatar image is not square" : "Imazhi avatar nuk është katror",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
    "Afghanistan" : "Afganistani",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Shqipëria",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktiku",
    "Argentina" : "Argjentina",
    "American Samoa" : "Samoa Amerikane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ishujt Oland",
    "Azerbaijan" : "Azerbajxhani",
    "Bosnia and Herzegovina" : "Bosnja and Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgjika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bullgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butani",
    "Botswana" : "Botsvana",
    "Belarus" : "Bjellorusi",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Zvicër",
    "Côte d'Ivoire" : "Bregu i Fildishtë",
    "Chile" : "Kili",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbi",
    "Cuba" : "Kubë",
    "Cabo Verde" : "Kepi i Gjelbër",
    "Cyprus" : "Qipro",
    "Germany" : "Gjermani",
    "Denmark" : "Danimarkë",
    "Algeria" : "Algjeria",
    "Ecuador" : "Ekuadori",
    "Estonia" : "Estonia",
    "Egypt" : "Egjipt",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlanda",
    "Fiji" : "Fixhi",
    "France" : "Franca",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Mbretëria e Bashkuar e Britanisë së Madhe dhe Irlandës Veriore",
    "Georgia" : "Gjeorgji",
    "Ghana" : "Gana",
    "Gibraltar" : "Gjibraltar",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Greece" : "Greqi",
    "Guatemala" : "Guatemala",
    "Honduras" : "Honduras",
    "Croatia" : "Kroaci",
    "Haiti" : "Haiti",
    "Hungary" : "Hungari",
    "Indonesia" : "Indonezia",
    "Ireland" : "Irlanda",
    "Israel" : "Izraeli",
    "India" : "India",
    "Iraq" : "Irak",
    "Iceland" : "Islanda",
    "Italy" : "Itali",
    "Jamaica" : "Xhamaika",
    "Jordan" : "Jordani",
    "Japan" : "Japoni",
    "Kenya" : "Kenia",
    "Cambodia" : "Kamboxhia",
    "Kiribati" : "Kiribati",
    "Kuwait" : "Kuvajti",
    "Kazakhstan" : "Kazakistani",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luksemburgu",
    "Libya" : "Libia",
    "Morocco" : "Maroku",
    "Montenegro" : "Mali i Zi",
    "Mali" : "Mali",
    "Mongolia" : "Mongolia",
    "Malta" : "Malta",
    "Mexico" : "Meksikë",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollandë",
    "Norway" : "Norvegji",
    "Nepal" : "Nepal",
    "New Zealand" : "Zelanda e Re",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Poloni",
    "Puerto Rico" : "Puerto Riko",
    "Portugal" : "Portugali",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Qatar",
    "Romania" : "Rumania",
    "Serbia" : "Serbi",
    "Russian Federation" : "Federata Ruse",
    "Saudi Arabia" : "Arabia Saudite",
    "Sudan" : "Sudan",
    "Sweden" : "Suedi",
    "Singapore" : "Singapori",
    "Slovenia" : "Sllovenia",
    "Slovakia" : "Sllovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegali",
    "Somalia" : "Somalia",
    "Syrian Arab Republic" : "Republika Arabe e Sirisë",
    "Chad" : "Çad",
    "Togo" : "Togo",
    "Thailand" : "Tajlanda",
    "Tajikistan" : "Taxhikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tonga",
    "Turkey" : "Turqi",
    "Ukraine" : "Ukrainë",
    "Uganda" : "Uganda",
    "United States of America" : "Shtetet e Bashkuara të Amerikës",
    "Uruguay" : "Uruguaj",
    "Zambia" : "Zambia",
    "Federation" : "Federim",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Leave call" : "Lini një thirrje",
    "Everyone" : "Kushdo",
    "Save changes" : "Ruaj ndryshimet",
    "Saved!" : "I/E ruajtur!",
    "Limit to groups" : "Kufizo grupet",
    "Enabled" : "E aktivizuar",
    "Disabled" : "I çaktivizuar",
    "State" : "Gjendja",
    "Name" : "Emri",
    "Permissions" : "Lejet",
    "General settings" : "Opsjonet e Pergjithshme",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Pending" : "Në Pritje të Konfirmimit",
    "Error" : "Error",
    "Blocked" : "I bllokuar",
    "Language" : "Gjuha",
    "Country" : "Vend",
    "Status" : "Status",
    "Created at" : "U krijua në",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "OK" : "OK",
    "Checking …" : "Duke kontrolluar ...",
    "Confirm" : "Konfirmo",
    "Reset" : "Rivendos",
    "Back" : "Prapa",
    "Cancel" : "Anullo",
    "Calendar" : "Kalendar",
    "Attendees" : "Pjesëmarrës",
    "Save" : "Ruaj",
    "No results" : "Asnjë rezultat",
    "Done" : "U bë",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Copy link" : "Kopjo linkun",
    "Mute audio" : "Mute audio",
    "Disable video" : "Çaktivizo video",
    "You" : "Ju",
    "Collapse" : "Tkurre",
    "Favorite" : "I/E Preferuar",
    "Hide details" : "Fsheh detajet",
    "Disable" : "Çaktivizoje",
    "Enable" : "Aktivizoje",
    "Choose" : "Zgjidhni",
    "Restricted" : "I/E kufizuar",
    "Personal" : "Personale",
    "Leave conversation" : "Largohuni nga biseda",
    "Yes" : "Po",
    "Delete conversation" : "Fshijeni bisedën",
    "Password protection" : "Password protection",
    "Set a password" : "Vendosni një fjalëkalim",
    "Edit" : "Përpuno",
    "Delete" : "Fshij",
    "Log content" : "Përmbajtja e hyrjes",
    "Notifications" : "Njoftimet",
    "Log in" : "Hyni",
    "Mark as read" : "Shënoje si të lexuar",
    "Mark as unread" : "Shënoje si të palexuar",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "Users" : "Përdoruesit",
    "Groups" : "Grupet",
    "None" : "Asnjë",
    "Devices" : "Pajisjet",
    "Upload" : "Ngarkoni",
    "Files" : "Skedarët",
    "Message sent" : "Mesazhi u dërgua",
    "Reply" : "Përgjigju",
    "Translate" : "Përkthe",
    "Dismiss" : "Hiq",
    "Contact" : "Kontakt",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
    "Send message" : "Dërgo mesazh",
    "Create new poll" : "Krijo sondazh të ri",
    "New file" : "Skedë e re",
    "Send" : "Dërgo",
    "Create poll" : "Krijo sondazh",
    "Settings" : "Rregullimet",
    "guest" : "vizitor",
    "Remove" : "Hiqe",
    "Add users or groups" : "Add users or groups",
    "Details" : "Detajet",
    "Privacy" : "Privatësia",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Search" : "Kërko",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Grid view" : "Pamje galeri",
    "Keep" : "Mbaje",
    "Submit" : "Dërgo",
    "User" : "Përdorues",
    "Password" : "Fjalëkalim",
    "API token" : "Çelës identifikues i API-t ",
    "Login" : "Hyrje",
    "Nickname" : "Nofkë",
    "Client ID" : "ID klienti",
    "Media" : "Media",
    "Polls" : "Sondazhe",
    "Audio" : "Audio",
    "Other" : "Tjetër",
    "Group" : "Grup",
    "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
    "Default" : "E paracaktuar",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
    "Android app" : "Aplikacion Android",
    "iOS app" : "Aplikacion iOS",
    "__language_name__" : "Shqip",
    "Tasks" : "Detyra",
    "Close" : "Mbylleni"
},
"nplurals=2; plural=(n != 1);");
